summaryrefslogtreecommitdiff
path: root/src/mongo/s/client/shard_local.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/client/shard_local.h')
-rw-r--r--src/mongo/s/client/shard_local.h29
1 files changed, 14 insertions, 15 deletions
diff --git a/src/mongo/s/client/shard_local.h b/src/mongo/s/client/shard_local.h
index 75e97ed0d29..7a4169655b1 100644
--- a/src/mongo/s/client/shard_local.h
+++ b/src/mongo/s/client/shard_local.h
@@ -58,10 +58,10 @@ public:
bool isRetriableError(ErrorCodes::Error code, RetryPolicy options) final;
- Status createIndexOnConfig(OperationContext* txn,
- const NamespaceString& ns,
- const BSONObj& keys,
- bool unique) override;
+ Status createIndex(OperationContext* txn,
+ const NamespaceString& ns,
+ const BSONObj& keys,
+ bool unique) override;
private:
Shard::HostWithResponse _runCommand(OperationContext* txn,
@@ -70,14 +70,13 @@ private:
Milliseconds maxTimeMSOverrideUnused,
const BSONObj& cmdObj) final;
- StatusWith<Shard::QueryResponse> _exhaustiveFindOnConfig(
- OperationContext* txn,
- const ReadPreferenceSetting& readPref,
- const repl::ReadConcernLevel& readConcernLevel,
- const NamespaceString& nss,
- const BSONObj& query,
- const BSONObj& sort,
- boost::optional<long long> limit) final;
+ StatusWith<Shard::QueryResponse> _exhaustiveFind(OperationContext* txn,
+ const ReadPreferenceSetting& readPref,
+ const repl::ReadConcernLevel& readConcernLevel,
+ const NamespaceString& nss,
+ const BSONObj& query,
+ const BSONObj& sort,
+ boost::optional<long long> limit) final;
/**
* Checks if an OpTime was set on the current Client (ie if the current operation performed a
@@ -99,9 +98,9 @@ private:
stdx::mutex _mutex;
// Stores the optime that was generated by the last operation to perform a write that was run
// through _runCommand. Used in _exhaustiveFindOnConfig for waiting for that optime to be
// committed so that readConcern majority reads will read the writes that were performed without
// a w:majority write concern.
repl::OpTime _lastOpTime{};
};
@@ -99,9 +98,9 @@ private:
stdx::mutex _mutex;
// Stores the optime that was generated by the last operation to perform a write that was run
- // through _runCommand. Used in _exhaustiveFindOnConfig for waiting for that optime to be
- // committed so that readConcern majority reads will read the writes that were performed without
- // a w:majority write concern.
+ // through _runCommand. Used in _exhaustiveFind for waiting for that optime to be committed so
+ // that readConcern majority reads will read the writes that were performed without a w:majority
+ // write concern.
repl::OpTime _lastOpTime{};
};